@@ -77,6 +77,8 @@ typedef enum
     BPROTO_REQ_GROUPS,                  /* empty                            */
     BPROTO_ENABLE_BACKUP_MODE,          /* empty                            */
     BPROTO_DISABLE_BACKUP_MODE,         /* empty                            */
+    BPROTO_TEE_PIPE_NAME_UPDATE,        /* tee pipe name                    */
+    BPROTO_DROP_DATABASE,               /* empty                            */
 } bproto_client_t;
 
 /*
@@ -123,7 +125,9 @@ typedef enum
     BPROTO_ACK_DROP_SERIES,                     /* empty                    */
     BPROTO_ACK_ENABLE_BACKUP_MODE,              /* empty                    */
     BPROTO_ACK_DISABLE_BACKUP_MODE,             /* empty                    */
-    BPROTO_RES_GROUPS                           /* [[name, series], ...]    */
+    BPROTO_RES_GROUPS,                          /* [[name, series], ...]    */
+    BPROTO_ACK_TEE_PIPE_NAME,                   /* empty                    */
+    BPROTO_ACK_DROP_DATABASE,                   /* empty                    */
 
 } bproto_server_t;
 
