@@ -21,16 +21,24 @@ from testing import TestBase
 from testing import UserAuthError
 from testing import parse_args
 
-
+LENPOINTS = 70
 DATA = {
-    'series float': [
+    'series-001 float': [
         [1471254705, 1.5],
         [1471254707, -3.5],
         [1471254710, -7.3]],
-    'series integer': [
+    'series-001 integer': [
         [1471254705, 5],
         [1471254708, -3],
         [1471254710, -7]],
+    'series-002 float': [
+        [1471254705, 3.5],
+        [1471254707, -2.5],
+        [1471254710, -8.3]],
+    'series-002 integer': [
+        [1471254705, 4],
+        [1471254708, -1],
+        [1471254710, -8]],
     'aggr': [
         [1447249033, 531], [1447249337, 534],
         [1447249633, 535], [1447249937, 531],
@@ -94,50 +102,63 @@ class TestSelect(TestBase):
 
         self.assertEqual(
             await self.client0.insert(DATA),
-            {'success_msg': 'Successfully inserted 64 point(s).'})
+            {'success_msg': 'Successfully inserted {} point(s).'.format(
+                LENPOINTS)})
 
         self.assertEqual(
             await self.client0.query(
-                'select difference() from "series integer"'),
-            {'series integer': [[1471254708, -8], [1471254710, -4]]})
+                'select difference() from "series-001 integer"'),
+            {'series-001 integer': [[1471254708, -8], [1471254710, -4]]})
 
         self.assertEqual(
             await self.client0.query(
-                'select difference() => difference() from "series integer"'),
-            {'series integer': [[1471254710, 4]]})
+                'select difference() => difference() '
+                'from "series-001 integer"'),
+            {'series-001 integer': [[1471254710, 4]]})
 
         self.assertEqual(
             await self.client0.query(
                 'select difference() => difference() => difference() '
-                'from "series integer"'),
-            {'series integer': []})
+                'from "series-001 integer"'),
+            {'series-001 integer': []})
 
         now = int(time.time())
         self.assertEqual(
             await self.client0.query(
-                'select difference({}) from "series integer"'.format(now)),
-            {'series integer': [[now, -12]]})
+                'select difference({}) from "series-001 integer"'.format(now)),
+            {'series-001 integer': [[now, -12]]})
 
         now = int(time.time())
         self.assertEqual(
             await self.client0.query(
-                'select difference({}) from "series integer"'.format(now)),
-            {'series integer': [[now, -12]]})
+                'select difference({}) from "series-001 integer"'.format(now)),
+            {'series-001 integer': [[now, -12]]})
 
         self.assertEqual(
             await self.client0.query(
-                'select * from /series.*/ '
+                'select * from /series-001.*/ '
                 'merge as "median_low" using median_low({})'
                 .format(now)),
             {'median_low': [[now, -3.5]]})
 
         self.assertEqual(
             await self.client0.query(
-                'select * from /series.*/ '
+                'select * from /series-001.*/ '
                 'merge as "median_high" using median_high({})'
                 .format(now)),
             {'median_high': [[now, -3.0]]})
 
+        self.assertEqual(
+            await self.client0.query(
+                'select * from /series.*/ '
+                'merge as "max" using max(1s)'),
+            {'max': [
+                [1471254705, 5.0],
+                [1471254707, -2.5],
+                [1471254708, -1.0],
+                [1471254710, -7.0]
+            ]})
+
         # Test all aggregation methods
 
         self.assertEqual(
@@ -248,8 +269,8 @@ class TestSelect(TestBase):
 
         self.assertEqual(
             await self.client0.query(
-                'select limit(2, max)  from "series float"'),
-            {'series float': [[1471254707, 1.5], [1471254713, -7.3]]})
+                'select limit(2, max)  from "series-001 float"'),
+            {'series-001 float': [[1471254707, 1.5], [1471254713, -7.3]]})
 
         self.assertAlmostEqual(
             await self.client0.query(
@@ -351,44 +372,44 @@ class TestSelect(TestBase):
 
         with self.assertRaisesRegex(
                 QueryError,
-                'Cannot use mean\(\) on string type\.'):
+                r'Cannot use mean\(\) on string type\.'):
             await self.client0.query('select mean(1w) from "log"')
 
         with self.assertRaisesRegex(
                 QueryError,
-                'Group by time must be an integer value larger than zero\.'):
+                r'Group by time must be an integer value larger than zero\.'):
             await self.client0.query('select mean(0) from "aggr"')
 
         with self.assertRaisesRegex(
                 QueryError,
-                'Limit must be an integer value larger than zero\.'):
+                r'Limit must be an integer value larger than zero\.'):
             await self.client0.query('select limit(6 - 6, mean) from "aggr"')
 
         with self.assertRaisesRegex(
                 QueryError,
-                'Cannot use a string filter on number type\.'):
+                r'Cannot use a string filter on number type\.'):
             await self.client0.query(
                 'select * from "aggr" '
                 'merge as "t" using filter("0")')
 
         with self.assertRaisesRegex(
                 QueryError,
-                'Cannot use difference\(\) on string type\.'):
+                r'Cannot use difference\(\) on string type\.'):
             await self.client0.query('select difference() from "log"')
 
         with self.assertRaisesRegex(
                 QueryError,
-                'Cannot use derivative\(\) on string type\.'):
+                r'Cannot use derivative\(\) on string type\.'):
             await self.client0.query('select derivative(6, 3) from "log"')
 
         with self.assertRaisesRegex(
                 QueryError,
-                'Cannot use derivative\(\) on string type\.'):
+                r'Cannot use derivative\(\) on string type\.'):
             await self.client0.query('select derivative() from "log"')
 
         with self.assertRaisesRegex(
                 QueryError,
-                'Overflow detected while using sum\(\)\.'):
+                r'Overflow detected while using sum\(\)\.'):
             await self.client0.query('select sum(now) from "huge"')
 
         with self.assertRaisesRegex(
@@ -425,7 +446,7 @@ class TestSelect(TestBase):
             await self.client0.query(
                 'select min(2h) prefix "min-", max(1h) prefix "max-" '
                 'from /.*/ where type == integer and name != "filter" '
-                'and name != "one"'
+                'and name != "one" and name != "series-002 integer" '
                 'merge as "int_min_max" using median_low(1) => difference()'),
             {
                 'max-int_min_max': [
@@ -487,8 +508,6 @@ class TestSelect(TestBase):
 
         self.client0.close()
 
-        # return False
-
 
 if __name__ == '__main__':
     parse_args()
