@@ -10,6 +10,7 @@
 #include <siri/db/time.h>
 #include <siri/grammar/grammar.h>
 #include <siri/db/fifo.h>
+#include <siri/db/tee.h>
 #include <siri/net/tcp.h>
 #include <siri/siri.h>
 #include <siri/version.h>
@@ -139,6 +140,10 @@ static void prop_sync_progress(
         siridb_t * siridb,
         qp_packer_t * packer,
         int map);
+static void prop_tee_pipe_name(
+        siridb_t * siridb,
+        qp_packer_t * packer,
+        int map);
 static void prop_timezone(
         siridb_t * siridb,
         qp_packer_t * packer,
@@ -231,6 +236,8 @@ void siridb_init_props(void)
             prop_status;
     siridb_props[CLERI_GID_K_SYNC_PROGRESS - KW_OFFSET] =
             prop_sync_progress;
+    siridb_props[CLERI_GID_K_TEE_PIPE_NAME - KW_OFFSET] =
+            prop_tee_pipe_name;
     siridb_props[CLERI_GID_K_TIMEZONE - KW_OFFSET] =
             prop_timezone;
     siridb_props[CLERI_GID_K_TIME_PRECISION - KW_OFFSET] =
@@ -251,7 +258,7 @@ static void prop_active_handles(
         int map)
 {
     SIRIDB_PROP_MAP("active_handles", 14)
-    qp_add_int32(packer, (int32_t) siri.loop->active_handles);
+    qp_add_int64(packer, (int64_t) siri.loop->active_handles);
 }
 
 static void prop_active_tasks(
@@ -260,7 +267,7 @@ static void prop_active_tasks(
         int map)
 {
     SIRIDB_PROP_MAP("active_tasks", 12)
-    qp_add_int32(packer, (int32_t) siridb->tasks.active);
+    qp_add_int64(packer, (int64_t) siridb->tasks.active);
 }
 
 static void prop_buffer_path(
@@ -278,7 +285,7 @@ static void prop_buffer_size(
         int map)
 {
     SIRIDB_PROP_MAP("buffer_size", 11)
-    qp_add_int32(packer, (int32_t) siridb->buffer->size);
+    qp_add_int64(packer, (int64_t) siridb->buffer->size);
 }
 
 static void prop_dbname(
@@ -332,7 +339,7 @@ static void prop_fifo_files(
         int map)
 {
     SIRIDB_PROP_MAP("fifo_files", 10)
-    qp_add_int32(packer, (int32_t) siridb_fifo_size(siridb->fifo));
+    qp_add_int64(packer, (int64_t) siridb_fifo_size(siridb->fifo));
 }
 
 static void prop_idle_percentage(
@@ -341,7 +348,7 @@ static void prop_idle_percentage(
         int map)
 {
     SIRIDB_PROP_MAP("idle_percentage", 15)
-    qp_add_int8(packer, siridb_get_idle_percentage(siridb));
+    qp_add_int64(packer, siridb_get_idle_percentage(siridb));
 }
 
 static void prop_idle_time(
@@ -350,7 +357,7 @@ static void prop_idle_time(
         int map)
 {
     SIRIDB_PROP_MAP("idle_time", 9)
-    qp_add_int32(packer, (int32_t) siridb->tasks.idle_time);
+    qp_add_int64(packer, (int64_t) siridb->tasks.idle_time);
 }
 
 static void prop_ip_support(
@@ -395,7 +402,7 @@ static void prop_max_open_files(
         int map)
 {
     SIRIDB_PROP_MAP("max_open_files", 14)
-    qp_add_int32(packer, (int32_t) siri.cfg->max_open_files);
+    qp_add_int64(packer, (int64_t) siri.cfg->max_open_files);
 }
 
 static void prop_mem_usage(
@@ -404,7 +411,7 @@ static void prop_mem_usage(
         int map)
 {
     SIRIDB_PROP_MAP("mem_usage", 9)
-    qp_add_int32(packer, (int32_t) (procinfo_total_physical_memory() / 1024));
+    qp_add_int64(packer, (int64_t) (procinfo_total_physical_memory() / 1024));
 }
 
 static void prop_open_files(
@@ -413,7 +420,7 @@ static void prop_open_files(
         int map)
 {
     SIRIDB_PROP_MAP("open_files", 10)
-    qp_add_int32(packer, (int32_t) siridb_open_files(siridb));
+    qp_add_int64(packer, (int64_t) siridb_open_files(siridb));
 }
 
 static void prop_pool(
@@ -422,7 +429,7 @@ static void prop_pool(
         int map)
 {
     SIRIDB_PROP_MAP("pool", 4)
-    qp_add_int16(packer, (int16_t) siridb->server->pool);
+    qp_add_int64(packer, (int64_t) siridb->server->pool);
 }
 
 static void prop_received_points(
@@ -476,7 +483,7 @@ static void prop_startup_time(
         int map)
 {
     SIRIDB_PROP_MAP("startup_time", 12)
-    qp_add_int32(packer, (int32_t) siri.startup_time);
+    qp_add_int64(packer, (int64_t) siri.startup_time);
 }
 
 static void prop_status(
@@ -499,6 +506,15 @@ static void prop_sync_progress(
     qp_add_string(packer, siridb_initsync_sync_progress(siridb));
 }
 
+static void prop_tee_pipe_name(
+        siridb_t * siridb,
+        qp_packer_t * packer,
+        int map)
+{
+    SIRIDB_PROP_MAP("tee_pipe_name", 13)
+    qp_add_string(packer, tee_str(siridb->tee));
+}
+
 static void prop_timezone(
         siridb_t * siridb,
         qp_packer_t * packer,
@@ -527,7 +543,7 @@ static void prop_uptime(
         int map)
 {
     SIRIDB_PROP_MAP("uptime", 6)
-    qp_add_int32(packer, siridb_get_uptime(siridb));
+    qp_add_int64(packer, siridb_get_uptime(siridb));
 }
 
 static void prop_uuid(
