@@ -35,7 +35,6 @@
 #define SIRIDB_DROPPED_FN ".dropped"
 #define SIRIDB_MAX_SERIES_ID_FN ".max_series_id"
 #define SIRIDB_SERIES_SCHEMA 1
-#define BEND series->buffer->points->data[series->buffer->points->len - 1].ts
 #define DROPPED_DUMMY 1
 
 /*
@@ -275,8 +274,8 @@ siridb_series_t * siridb_series_new(
                 siridb->store,
                 (const unsigned char *) series_name,
                 series->name_len + 1) ||
-        qp_fadd_int32(siridb->store, (int32_t) series->id) ||
-        qp_fadd_int8(siridb->store, (int8_t) series->tp) ||
+        qp_fadd_int64(siridb->store, (int64_t) series->id) ||
+        qp_fadd_int64(siridb->store, (int64_t) series->tp) ||
         qp_flush(siridb->store))
     {
         ERR_FILE
@@ -705,7 +704,8 @@ siridb_points_t * siridb_series_get_points(
 
     if (points == NULL)
     {
-        return NULL;  /* signal is raised */
+        ERR_ALLOC  /* TODO: maybe remove ERR_ALLOC */
+        return NULL;
     }
 
     for (i = 0; i < len; i++)
@@ -1081,7 +1081,9 @@ int siridb_series_optimize_shard(
     points = siridb_points_new(size, series->tp);
     if (points == NULL)
     {
-        return -1;  /* signal is raised */
+        /* TODO: check if we can remove this ERR_ALLOC */
+        ERR_ALLOC
+        return -1;
     }
 
     for (i = start; i < end; i++)
@@ -1315,8 +1317,7 @@ static siridb_series_t * SERIES_new(
         const char * name)
 {
     uint32_t n;
-    siridb_series_t * series;
-    series = (siridb_series_t *) malloc(sizeof(siridb_series_t));
+    siridb_series_t * series = malloc(sizeof(siridb_series_t));
     if (series == NULL)
     {
         ERR_ALLOC
@@ -1388,8 +1389,8 @@ static inline int SERIES_pack(siridb_series_t * series, qp_fpacker_t * fpacker)
                     fpacker,
                     (unsigned char *) series->name,
                     series->name_len + 1) ||
-            qp_fadd_int32(fpacker, (int32_t) series->id) ||
-            qp_fadd_int8(fpacker, (int8_t) series->tp));
+            qp_fadd_int64(fpacker, (int64_t) series->id) ||
+            qp_fadd_int64(fpacker, (int64_t) series->tp));
 }
 
 /*
@@ -1417,7 +1418,7 @@ static int SERIES_save(siridb_t * siridb)
         qp_fadd_type(fpacker, QP_ARRAY_OPEN) ||
 
         /* write the current schema */
-        qp_fadd_int16(fpacker, SIRIDB_SERIES_SCHEMA))
+        qp_fadd_int64(fpacker, SIRIDB_SERIES_SCHEMA))
     {
         ERR_FILE
     }
@@ -1471,7 +1472,7 @@ static int SERIES_read_dropped(siridb_t * siridb, imap_t * dropped)
     else if (size)
     {
 
-        buffer = (char *) malloc(size);
+        buffer = malloc(size);
         if (buffer == NULL)
         {
             log_critical("Cannot allocate buffer for reading dropped series");
